Examples
========

The following notebooks demonstrate capabilities of the PyGeoHydro software stack.

.. toctree::
    :maxdepth: 1

    examples/webservices
    examples/nwis
    examples/nid
    examples/nhdplus
    examples/daymet
    examples/nlcd
    examples/3dep
    examples/ssebop
